@@ -1,4 +1,4 @@
-#package Sim::OPT::Interlinear;
+package Sim::OPT::Interlinear;
 
 # INTERLINEAR
 # Author: Gian Luca Brunetti, Politecnico di Milano. (gianluca.brunetti@polimi.it)
@@ -31,7 +31,7 @@ use Sim::OPT::Parcoord3d;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.109';
+$VERSION = '0.111';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -40,7 +40,7 @@ $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, m
 
 $tee = new IO::Tee(\*STDOUT, ">>$report"); # GLOBAL ZZZ
 my $maxloops= 1000;
-my $sourcefile = "./sourcefile.csv";
+my $sourcefile = "./minitintcleaned.csv";
 my $newfile = $sourcefile . "_meta.csv";
 my $report = $newfile . "_report.txt";
 my @mode = ( "wei" ); # #"wei" is weighted gradient linear interpolation of the nearest neighbours.
